summaryrefslogtreecommitdiff
path: root/atspi/atspi-collection.c
diff options
context:
space:
mode:
authorMike Gorse <mgorse@novell.com>2012-02-03 17:21:33 -0600
committerMike Gorse <mgorse@novell.com>2012-02-03 17:23:20 -0600
commit1fe074c83b7290856957be1402aed3ca174c11e1 (patch)
treec35a8c0ef01a04417e42ba2ccc195ba5d1de509b /atspi/atspi-collection.c
parent627e95de50cb101207c057a85f594270d0340d75 (diff)
downloadat-spi2-core-1fe074c83b7290856957be1402aed3ca174c11e1.tar.gz
For atspi_collection_get_matches_to, rename restrict to limit_scope
Restrict can be a keyword. Don't use it as a variable name. Also update D-Bus introspection. https://bugzilla.gnome.org/show_bug.cgi?id=669344
Diffstat (limited to 'atspi/atspi-collection.c')
-rw-r--r--atspi/atspi-collection.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/atspi/atspi-collection.c b/atspi/atspi-collection.c
index a9657572..b401d109 100644
--- a/atspi/atspi-collection.c
+++ b/atspi/atspi-collection.c
@@ -166,7 +166,7 @@ atspi_collection_get_matches (AtspiCollection *collection,
* @tree: An #AtspiCollectionTreeTraversalType specifying restrictions on
* the objects to be traversed.
*
* @restrict: If #TRUE, only descendants of @current_object's parent
* will be returned. Otherwise (if #FALSE), any accessible may be returned
* if it would preceed @current_object in a flattened hierarchy.
*
@@ -187,7 +187,7 @@ atspi_collection_get_matches_to (AtspiCollection *collection,
AtspiMatchRule *rule,
AtspiCollectionSortOrder sortby,
AtspiCollectionTreeTraversalType tree,
- gboolean restrict,
+ gboolean limit_scope,
gint count,
gboolean traverse,
GError **error)
@@ -196,7 +196,7 @@ atspi_collection_get_matches_to (AtspiCollection *collection,
DBusMessage *reply;
dbus_int32_t d_sortby = sortby;
dbus_int32_t d_tree = tree;
- dbus_bool_t d_restrict = restrict;
+ dbus_bool_t d_limit_scope = limit_scope;
dbus_int32_t d_count = count;
dbus_bool_t d_traverse = traverse;
@@ -209,7 +209,7 @@ atspi_collection_get_matches_to (AtspiCollection *collection,
return NULL;
dbus_message_append_args (message, DBUS_TYPE_UINT32, &d_sortby,
DBUS_TYPE_UINT32, &d_tree,
- DBUS_TYPE_BOOLEAN, &d_restrict,
+ DBUS_TYPE_BOOLEAN, &d_limit_scope,
DBUS_TYPE_INT32, &d_count,
DBUS_TYPE_BOOLEAN, &d_traverse,
DBUS_TYPE_INVALID);
@@ -166,7 +166,7 @@ atspi_collection_get_matches (AtspiCollection *collection,
* the objects to be traversed.
*
- * @restrict: If #TRUE, only descendants of @current_object's parent
+ * @limit_scope: If #TRUE, only descendants of @current_object's parent
* will be returned. Otherwise (if #FALSE), any accessible may be returned
* if it would preceed @current_object in a flattened hierarchy.